2.0
===

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

1.3
===

Refresh package metadata (skeleton).

1.2
===

Refresh project skeleton.

1.1
===

Rebuild project with updated skeleton, adding automated deployment,
wheel distributions, tox test runs, and other things.
